[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Message-Id: <1421991416-20297-16-git-send-email-jiang.liu@linux.intel.com>
Date: Fri, 23 Jan 2015 13:36:54 +0800
From: Jiang Liu <jiang.liu@...ux.intel.com>
To: Thomas Gleixner <tglx@...utronix.de>, Jens Axboe <axboe@...com>,
Frederic Weisbecker <fweisbec@...il.com>,
Andrew Morton <akpm@...ux-foundation.org>,
Jan Kara <jack@...e.cz>, Christoph Hellwig <hch@...radead.org>,
Paul Gortmaker <paul.gortmaker@...driver.com>,
Jiang Liu <jiang.liu@...ux.intel.com>,
"Srivatsa S. Bhat" <srivatsa.bhat@...ux.vnet.ibm.com>,
Chuansheng Liu <chuansheng.liu@...el.com>,
Roman Gushchin <klamm@...dex-team.ru>
Cc: Borislav Petkov <bp@...en8.de>, Tony Luck <tony.luck@...el.com>,
linux-kernel@...r.kernel.org
Subject: [Resend Patch v4 15/16] smp: Cleanup unsued generic_smp_call_function_single_interrupt()
Now we have killed all usage of generic_smp_call_function_single_interrupt()
from arch code, so kill it.
Signed-off-by: Jiang Liu <jiang.liu@...ux.intel.com>
---
include/linux/smp.h | 4 +---
kernel/smp.c | 4 ++--
2 files changed, 3 insertions(+), 5 deletions(-)
diff --git a/include/linux/smp.h b/include/linux/smp.h
index 93dff5fff524..cd78b3aa2cf8 100644
--- a/include/linux/smp.h
+++ b/include/linux/smp.h
@@ -106,9 +106,7 @@ void wake_up_all_idle_cpus(void);
* Generic and arch helpers
*/
void __init call_function_init(void);
-void generic_smp_call_function_single_interrupt(void);
-#define generic_smp_call_function_interrupt \
- generic_smp_call_function_single_interrupt
+void generic_smp_call_function_interrupt(void);
/*
* Mark the boot cpu "online" so that it can call console drivers in
diff --git a/kernel/smp.c b/kernel/smp.c
index f38a1e692259..e39712cbe92d 100644
--- a/kernel/smp.c
+++ b/kernel/smp.c
@@ -197,12 +197,12 @@ static int generic_exec_single(int cpu, struct call_single_data *csd,
}
/**
* generic_smp_call_function_single_interrupt - Execute SMP IPI callbacks
*
* Invoked by arch to handle an IPI for call function single.
* Must be called with interrupts disabled.
*/
-void generic_smp_call_function_single_interrupt(void)
+void generic_smp_call_function_interrupt(void)
{
flush_smp_call_function_queue(true);
}
@@ -197,12 +197,12 @@ static int generic_exec_single(int cpu, struct call_single_data *csd,
}
/**
- * generic_smp_call_function_single_interrupt - Execute SMP IPI callbacks
+ * generic_smp_call_function_interrupt - Execute SMP IPI callbacks
*
* Invoked by arch to handle an IPI for call function single.
--
1.7.10.4
--
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@...r.kernel.org
More majordomo info at http://vger.kernel.org/majordomo-info.html
Please read the FAQ at http://www.tux.org/lkml/
Powered by blists - more mailing lists